[![PyPI version](https://badge.fury.io/py/unrealai.svg)](https://badge.fury.io/py/unrealai)

[![Build Status](https://travis-ci.org/nishgaba-ai/unrealai.svg?branch=master)](https://travis-ci.org/nishgaba-ai/unrealai)

[![Coverage Status](https://coveralls.io/repos/github/nishgaba-ai/unrealai/badge.svg?branch=master)](https://coveralls.io/github/nishgaba-ai/unrealai?branch=master)




# unrealai
Image/Machine Learning Tool Interface


# Installation
Run the following to install:

'''python
pip install unrealai
'''

## Usage
'''python
from helloworld import say_hello

# Generate "Hello, World!"
say_hello()

# Generate "Hello, Everybody!"
say_hello("Everybody")
'''
